@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
-from django.utils.translation import ugettext_lazy as _
 from django.conf import settings as django_settings
 
+CACHE_LOADER_NAME = 'django_mobile.loader.CachedLoader'
+DJANGO_MOBILE_LOADER = 'django_mobile.loader.Loader'
+
 
 class SettingsProxy(object):
     def __init__(self, settings, defaults):
@@ -15,7 +17,7 @@ class SettingsProxy(object):
             try:
                 return getattr(self.defaults, attr)
             except AttributeError:
-                raise AttributeError, u'settings object has no attribute "%s"' % attr
+                raise AttributeError(u'settings object has no attribute "%s"' % attr)
 
 
 class defaults(object):
@@ -29,9 +31,12 @@ class defaults(object):
     FLAVOURS_SESSION_KEY = u'flavour'
     FLAVOURS_TEMPLATE_LOADERS = []
     for loader in django_settings.TEMPLATE_LOADERS:
-        if loader != 'django_mobile.loader.Loader':
+        if isinstance(loader, (tuple, list)) and loader[0] == CACHE_LOADER_NAME:
+            for cached_loader in loader[1]:
+                if cached_loader != DJANGO_MOBILE_LOADER:
+                    FLAVOURS_TEMPLATE_LOADERS.append(cached_loader)
+        elif loader != DJANGO_MOBILE_LOADER:
             FLAVOURS_TEMPLATE_LOADERS.append(loader)
     FLAVOURS_TEMPLATE_LOADERS = tuple(FLAVOURS_TEMPLATE_LOADERS)
 
-
 settings = SettingsProxy(django_settings, defaults)
